pub struct ExperimentArtifactClient { /* private fields */ }Expand description
A scope for artifact operations within a specific experiment
Implementations
Sourceimpl ExperimentArtifactClient
impl ExperimentArtifactClient
Sourcepub fn upload<E>(
&self,
name: impl Into<String>,
kind: ArtifactKind,
artifact: E,
settings: &<E as BundleEncode>::Settings,
) -> Result<String, ArtifactError>where
E: BundleEncode,
pub fn upload<E>(
&self,
name: impl Into<String>,
kind: ArtifactKind,
artifact: E,
settings: &<E as BundleEncode>::Settings,
) -> Result<String, ArtifactError>where
E: BundleEncode,
Upload an artifact using the BundleEncode trait
Sourcepub fn download<D>(
&self,
name: impl AsRef<str>,
settings: &<D as BundleDecode>::Settings,
) -> Result<D, ArtifactError>where
D: BundleDecode,
pub fn download<D>(
&self,
name: impl AsRef<str>,
settings: &<D as BundleDecode>::Settings,
) -> Result<D, ArtifactError>where
D: BundleDecode,
Download an artifact and decode it using the BundleDecode trait
Sourcepub fn download_raw(
&self,
name: impl AsRef<str>,
) -> Result<InMemoryBundleReader, ArtifactError>
pub fn download_raw( &self, name: impl AsRef<str>, ) -> Result<InMemoryBundleReader, ArtifactError>
Download an artifact as a raw memory bundle reader
Sourcepub fn fetch(
&self,
name: impl AsRef<str>,
) -> Result<ArtifactResponse, ArtifactError>
pub fn fetch( &self, name: impl AsRef<str>, ) -> Result<ArtifactResponse, ArtifactError>
Fetch information about an artifact by name