pub struct CancelToken { /* private fields */ }Expand description
A cancellation token that can be shared across tasks. When cancelled, it will cancel all linked child tasks/tokens. Thread-safe and can be cloned.
Implementations
Sourceimpl CancelToken
impl CancelToken
Sourcepub fn new() -> CancelToken
pub fn new() -> CancelToken
Create a new cancellation token that is not cancelled and has no children.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if this token has been cancelled. Thread-safe.
Sourcepub fn link<T>(&self, child: T)where
T: Cancellable + 'static,
pub fn link<T>(&self, child: T)where
T: Cancellable + 'static,
Attach a child task/token to be cancelled when this token is cancelled. If already cancelled, child is cancelled immediately.
Sourcepub fn into_linked<T>(&self) -> T
pub fn into_linked<T>(&self) -> T
Create a new cancellable task/token of type T, link it to this token, and return it. See Self::link for more details.
Sourcepub fn linked<T>(&self, child: T) -> Twhere
T: Cancellable + Clone + 'static,
pub fn linked<T>(&self, child: T) -> Twhere
T: Cancellable + Clone + 'static,
Link an existing cancellable task/token of type T to this token and return it. See Self::link for more details.