ExperimentRun

Struct ExperimentRun 

pub struct ExperimentRun { /* private fields */ }
Represents an experiment in Burn Central, which is a run of a machine learning model or process.

Implementations

Source

impl ExperimentRun

pub fn new( burn_client: Client, namespace: &str, project_name: &str, experiment_num: i32, ) -> Result<ExperimentRun, ExperimentTrackerError>

pub fn handle(&self) -> ExperimentRunHandle

Returns a handle to the experiment, allowing logging of artifacts, metrics, and messages.

pub fn id(&self) -> &ExperimentPath

pub fn finish(self) -> Result<(), ExperimentTrackerError>

pub fn fail( self, reason: impl Into<String>, ) -> Result<(), ExperimentTrackerError>

Methods from Deref<Target = ExperimentRunHandle>

pub fn log_args<A>(&self, args: &A) -> Result<(), ExperimentTrackerError>
where A: Serialize,

Log arguments used to launch this experiment

pub fn log_artifact<E>( &self, name: impl Into<String>, kind: ArtifactKind, sources: E, settings: &<E as BundleEncode>::Settings, ) -> Result<(), ExperimentTrackerError>
where E: BundleEncode,

Log an artifact with the given name, kind and settings.

pub fn load_artifact<D>( &self, name: impl AsRef<str>, settings: &<D as BundleDecode>::Settings, ) -> Result<D, ExperimentTrackerError>
where D: BundleDecode,

Loads an artifact with the given name and settings.

pub fn load_artifact_raw( &self, name: impl AsRef<str>, ) -> Result<InMemoryBundleReader, ExperimentTrackerError>

Loads a raw artifact with the given name.

pub fn log_metric( &self, epoch: usize, split: impl Into<String>, iteration: usize, items: Vec<MetricLog>, )

Logs a metric with the given name, epoch, iteration, value, and group.

pub fn try_log_metric( &self, epoch: usize, split: impl Into<String>, iteration: usize, items: Vec<MetricLog>, ) -> Result<(), ExperimentTrackerError>

Attempts to log a metric with the given name, epoch, iteration, value, and group.

pub fn log_metric_definition( &self, name: impl Into<String>, description: Option<String>, unit: Option<String>, higher_is_better: bool, ) -> Result<(), ExperimentTrackerError>

pub fn log_epoch_summary( &self, epoch: usize, split: String, best_metric_values: Vec<MetricLog>, ) -> Result<(), ExperimentTrackerError>

pub fn log_info(&self, message: impl Into<String>)

Logs an info message.

pub fn try_log_info( &self, message: impl Into<String>, ) -> Result<(), ExperimentTrackerError>

Attempts to log an info message.

pub fn log_error(&self, error: impl Into<String>)

Logs an error message.

pub fn try_log_error( &self, error: impl Into<String>, ) -> Result<(), ExperimentTrackerError>

Attempts to log an error message.

pub fn log_config<C>( &self, name: impl Into<String>, config: &C, ) -> Result<(), ExperimentTrackerError>
where C: Serialize,

pub fn is_cancelled(&self) -> Result<bool, ExperimentTrackerError>

Check whether the experiment has been cancelled (either locally or via server request). Returns an error if the experiment has already become inactive.

pub fn cancel_token(&self) -> Result<CancelToken, ExperimentTrackerError>

Returns the experiment cancel token.