pub struct ModelClient { /* private fields */ }Expand description
A scope for operations on a specific model within a project.
Implementations
Sourceimpl ModelClient
impl ModelClient
Sourcepub fn download<T>(
&self,
version: u32,
settings: &<T as BundleDecode>::Settings,
) -> Result<T, ModelError>where
T: BundleDecode,
pub fn download<T>(
&self,
version: u32,
settings: &<T as BundleDecode>::Settings,
) -> Result<T, ModelError>where
T: BundleDecode,
Download a specific version of this model and decode it using the BundleDecode trait. This allows reusing existing bundle decoders for models.
Sourcepub fn download_raw(
&self,
version: u32,
) -> Result<InMemoryBundleReader, ModelError>
pub fn download_raw( &self, version: u32, ) -> Result<InMemoryBundleReader, ModelError>
Download a specific version of this model as a memory reader for dynamic access.
Sourcepub fn fetch(&self, version: u32) -> Result<ModelVersionResponse, ModelError>
pub fn fetch(&self, version: u32) -> Result<ModelVersionResponse, ModelError>
Get information about a specific model version.
Sourcepub fn total_versions(&self) -> u64
pub fn total_versions(&self) -> u64
Get the total number of versions available for this model.