pub struct ModelRegistry { /* private fields */ }Expand description
An interface for downloading models from Burn Central.
Implementations
Sourceimpl ModelRegistry
impl ModelRegistry
pub fn new(client: Client) -> ModelRegistry
Sourcepub fn model(&self, model_path: ModelPath) -> Result<ModelClient, ModelError>
pub fn model(&self, model_path: ModelPath) -> Result<ModelClient, ModelError>
Create a scope for a specific model within a project.
Sourcepub fn download<T>(
&self,
model_path: ModelPath,
version: u32,
settings: &<T as BundleDecode>::Settings,
) -> Result<T, ModelError>where
T: BundleDecode,
pub fn download<T>(
&self,
model_path: ModelPath,
version: u32,
settings: &<T as BundleDecode>::Settings,
) -> Result<T, ModelError>where
T: BundleDecode,
Download a specific model version and decode it using the BundleDecode trait.
Sourcepub fn download_raw(
&self,
model_path: ModelPath,
version: u32,
) -> Result<InMemoryBundleReader, ModelError>
pub fn download_raw( &self, model_path: ModelPath, version: u32, ) -> Result<InMemoryBundleReader, ModelError>
Download a specific model version as a memory reader for dynamic access.