pub struct BurnCentral { /* private fields */ }Expand description
This struct provides the main interface to interact with Burn Central.
It wrap the burn_central_client Client and provides higher level methods to interact with experiments, models, and artifacts.
Implementations
Sourceimpl BurnCentral
impl BurnCentral
Sourcepub fn start_experiment(
&self,
namespace: &str,
project_name: &str,
digest: String,
routine: String,
) -> Result<ExperimentRun, BurnCentralError>
pub fn start_experiment( &self, namespace: &str, project_name: &str, digest: String, routine: String, ) -> Result<ExperimentRun, BurnCentralError>
Start a new experiment. This will create a new experiment on the Burn Central backend and start it.
pub fn artifacts( &self, owner: &str, project: &str, exp_num: i32, ) -> Result<ExperimentArtifactClient, BurnCentralError>
Sourcepub fn models(&self) -> ModelRegistry
pub fn models(&self) -> ModelRegistry
Create a model registry for downloading models from Burn Central. Models are project-scoped and identified by namespace/project/model_name.